# ServiceAccount

A service account is an account intended to represent a non-human user that needs to authenticate and be authorized to access data in the Agilicus API.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**metadata** | [**MetadataWithId**](MetadataWithId.md) |  | [optional] 
**spec** | [**ServiceAccountSpec**](ServiceAccountSpec.md) |  | 
**status** | [**ServiceAccountStatus**](ServiceAccountStatus.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


